%Metabolomic Data Analysis used in paper.

%Let X be matrix of raw Chenomx data (37 by 34 matrix where rows are metabolites
%and columns are NMR samples with columns 1-8 control, 9-18 NRAS-transformed cells,
%19-27 KRAS-transformed cells, and 28-34 HRAS-transformed cells).

%To generate total intensity normalized data, Xn;

for k=1:34;Xn(:,k)=X(:,k)/sum(X(:,k));end;

%To do pca on Xn, you type

[coeff,scores,latent,tsquared,explained]=pca(Xn'); %where X is a data matrix with the rows being the observations (say P, N, K, H cells)
coeff(:,1) %gives the loadings for PC1
coeff(:,2) %gives loadings for PC2
explained(1,1) %gives variance of PC1
explained(2,1) %gives variance of PC2;

scatter(coeff(:,1),coeff(:,2)) %(will generate scatter data in Fig. 2(A)). 
%Score plots of data
%control cells:
figure;
hold;
%control cells
scatter(scores(1:8,1),scores(1:8,2),'k*');[elx,ely]=ellipso(scores(1:8,1),scores(1:8,2),0.99,1);
plot(elx,ely,'k');
%NRAS-transformed cells
scatter(scores(9:18,1),scores(9:18,2),'bs');[elx,ely]=ellipso(scores(9:18,1),scores(9:18,2),0.99,1);
plot(elx,ely,'b');
%KRAS-transformed cells
scatter(scores(19:27,1),scores(19:27,2),'ro');[elx,ely]=ellipso(scores(19:27,1),scores(19:27,2),0.99,1);
plot(elx,ely,'r');
%HRAS-transformed cells
scatter(scores(28:34,1),scores(28:34,2),'gd');[elx,ely]=ellipso(scores(28:34,1),scores(28:34,2),0.99,1);
plot(elx,ely,'g');

%Anova Analysis of Xn
% define groups, ty:  
ty={'P','P','P','P','P','P','P','P','N','N','N','N','N','N','N','N','N','N','K','K','K','K','K','K','K','K','K','H','H','H','H','H','H','H'};

for k=1:37;[p,a]=anova1(Xn(k,:),ty');pval(k,1)=p;end;
% Determine metabolites where  <x^control> = <x^NRAS> = <x^KRAS>=<x^HRAS>
% fails at a false discovery rate of 0.01 using Benjamini-Yekutieli
% algorithm;  Xns are those metabolites where there is a significant
% difference, and Xmetabs lists the identitiy of those metabolites (index).

[aa,bb,cc]=fdr_bh(pval,0.01,'dep');
m=1;for k=1:37; if aa(k,1)==1;Xns(m,:)=Xn(k,:); Xmetabs(m,1)=k;m=m+1;end;end;

%Perform mutliple testing:
P=Xns(:,1:8);
N=Xns(:,9:18);
K=Xns(:,19:27);
H=Xns(:,28:34);
[h,pPN]=ttest2(P',N','Vartype','unequal'); %Welch's t-test for different size groups without assumption of equal variances.
[h,pPK]=ttest2(P',K','Vartype','unequal');
[h,pPH]=ttest2(P',H','Vartype','unequal');
[h,pNK]=ttest2(N',K','Vartype','unequal');
[h,pNH]=ttest2(N',H','Vartype','unequal');
[h,pKH]=ttest2(K',H','Vartype','unequal');

PP=[pPN;pPK;pPH;pNK;pNH;pKH];
[a,b]=size(PP);
PPt=reshape(PP,a*b,1);
[aam,bbm,ccm]=fdr_bh(PPt,0.01,'dep'); %Performs Benjamini-Yekutieli test with false discover rate of 0.01
aam=reshape(aam,a,b); % columns are those metabolites identified by ANOVA (Xmetabs(1,1) to Xmetabs(b,1)
%row indicates comparison between cell types  1 = control NRAS, 2 = control KRAS,
%3=control HRAS, 4 = NRAS/KRAS, 5= NRAS/HRAS; 6= KRAS/HRAS;
%if aam(j,k)=1 then there is a significant difference for metabolite
%Xmetabs(k,1) in the jth comparison.  
ccm=reshape(ccm,a,b);%adjusted p-values from BY algorithm given in Table S1 in Supplementary Matieral.


%To Generate glutamate normalized data (glutamate is 14th metabolite, 14th row), Xg;

for k=1:34; Xgtemp(:,k)=X(:,k)/X(14,k);end;

Xg=Xgtemp(1:13,:);Xg(14:36,:)=Xgtemp(15:37,:);

[coeff,scores,latent,tsquared,explained]=pca(Xg'); %where X is a data matrix with the rows being the observations (say P, N, K, H cells)
coeff(:,1) %gives the loadings for PC1
coeff(:,2) %gives loadings for PC2
explained(1,1) %gives variance of PC1
explained(2,1) %gives variance of PC2;
figure;
scatter(coeff(:,1),coeff(:,2)) %(will generate scatter data in Fig. 2(C)). 
%Score plots of data
%control cells:
figure;
hold;
%control cells
scatter(scores(1:8,1),scores(1:8,2),'k*');[elx,ely]=ellipso(scores(1:8,1),scores(1:8,2),0.99,1);
plot(elx,ely,'k');
%NRAS-transformed cells
scatter(scores(9:18,1),scores(9:18,2),'bs');[elx,ely]=ellipso(scores(9:18,1),scores(9:18,2),0.99,1);
plot(elx,ely,'b');
%KRAS-transformed cells
scatter(scores(19:27,1),scores(19:27,2),'ro');[elx,ely]=ellipso(scores(19:27,1),scores(19:27,2),0.99,1);
plot(elx,ely,'r');
%HRAS-transformed cells
scatter(scores(28:34,1),scores(28:34,2),'gd');[elx,ely]=ellipso(scores(28:34,1),scores(28:34,2),0.99,1);
plot(elx,ely,'g');

%Anova Analysis of Xg
% define groups, ty:  
ty={'P','P','P','P','P','P','P','P','N','N','N','N','N','N','N','N','N','N','K','K','K','K','K','K','K','K','K','H','H','H','H','H','H','H'};

for k=1:36;[p,a]=anova1(Xg(k,:),ty');pvalg(k,1)=p;end;
% Determine metabolites where  <x^control> = <x^NRAS> = <x^KRAS>=<x^HRAS>
% fails at a false discovery rate of 0.01 using Benjamini-Yekutieli
% algorithm;  Xgs are those metabolites where there is a significant
% difference, and Xmetabgs lists the identitiy of those metabolites (index).

[aa,bb,cc]=fdr_bh(pvalg,0.01,'dep');
m=1;for k=1:36; if aa(k,1)==1;Xgs(m,:)=Xg(k,:); Xmetabgs(m,1)=k;m=m+1;end;end;

%Perform mutliple testing:
P=Xgs(:,1:8);
N=Xgs(:,9:18);
K=Xgs(:,19:27);
H=Xgs(:,28:34);
[h,pPN]=ttest2(P',N','Vartype','unequal'); %Welch's t-test for different size groups without assumption of equal variances.
[h,pPK]=ttest2(P',K','Vartype','unequal');
[h,pPH]=ttest2(P',H','Vartype','unequal');
[h,pNK]=ttest2(N',K','Vartype','unequal');
[h,pNH]=ttest2(N',H','Vartype','unequal');
[h,pKH]=ttest2(K',H','Vartype','unequal');

PP=[pPN;pPK;pPH;pNK;pNH;pKH];
[a,b]=size(PP);
PPt=reshape(PP,a*b,1);
[aam,bbm,ccm]=fdr_bh(PPt,0.01,'dep'); %Performs Benjamini-Yekutieli test with false discover rate of 0.01
aam=reshape(aam,a,b); % columns are those metabolites identified by ANOVA (Xmetabs(1,1) to Xmetabs(b,1)
%row indicates comparison between cell types  1 = control NRAS, 2 = control KRAS,
%3=control HRAS, 4 = NRAS/KRAS, 5= NRAS/HRAS; 6= KRAS/HRAS;
%if aam(j,k)=1 then there is a significant difference for metabolite
%Xmetabs(k,1) in the jth comparison.  
ccm=reshape(ccm,a,b);%adjusted p-values from BY algorithm given in Table S1 in Supplementary Matieral.
for k=1:b;
    [fl,fu]=fieller(N(k,:)',P(k,:)',0.01);
    FL(1,k)=fl;
    FU(1,k)=fu;
    
    [fl,fu]=fieller(K(k,:)',P(k,:)',0.01);
    FL(2,k)=fl;
    FU(2,k)=fu;
    
    [fl,fu]=fieller(H(k,:)',P(k,:)',0.01);
    FL(3,k)=fl;
    FU(3,k)=fu;
    
    [fl,fu]=fieller(K(k,:)',N(k,:)',0.01);
    FL(4,k)=fl;
    FU(4,k)=fu;
    
    [fl,fu]=fieller(N(k,:)',H(k,:)',0.01);
    FL(5,k)=fl;
    FU(5,k)=fu;
    
    [fl,fu]=fieller(K(k,:)',H(k,:)',0.01);
    FL(6,k)=fl;
    FU(6,k)=fu;
end;
FL=FL.*aam;%FL represents lower limit of 99% confidence interval for only those comparisons determined to be significant by BY analysis.
FU=FU.*aam;%FU represents lower limit of 99% confidence interval for only those comparisons determined to be significant by BY analysis.
FM=1/2*(FL+FU); %middle of 99% confidence limit.
%
