function [elx,ely]=ellipso(X,Y,p,dimo);
%Plots 99% confidence ellipses.
%Example, let X and Y be the scores of PC1 and PC2 
%Then [elx,ely]=ellipso(X,Y,dim) gives the x coordinates (elx) and y
%coordinates (ely) of 100*p% confidence ellipse (dim=1 if X, Y are column vectors and dim=2
%if X and Y are row vectors.
%Typing the commands hold; scatter(X,Y,'k*'); plot(elx,ely,'k'); 
%The scores with be shown (represented by a black asterisk) along with the
%ellipse.
%Taken from Hoover (Algorithms for Confidence Circles and ellipses, 1984)
%To draw other ellipses at difference levels of confidence, simply change
%the factor 3.0349 below to ks=(-2*log(1-p))^0.5 where log is natural log and
%p is the confidence.  For example, for 99% confidence ellipse, p=0.99 and
%therefore ks= 3.0349.  For 95%, we would get ks = 2.4477. 
%ks=2.4477;
%ks=3.0349
ks=(-2*log(1-p))^0.5;
sumx=sum(X,dimo);
sumy=sum(Y,dimo);
sumxx=sum(X.*X,dimo);
sumyy=sum(Y.*Y,dimo);
sumxy=sum(X.*Y,dimo);
n=length(X)

xbar=sumx/n;
ybar=sumy/n;
varx=sumxx/(n-1);
vary=sumyy/(n-1);
covarxy=sumxy/(n-1) ;
dx=X-xbar;
dy=Y-ybar;
sumdxdx=sum(dx.*dx,dimo);
sumdydy=sum(dy.*dy,dimo);
sumdxdy=sum(dx.*dy,dimo);

theta=0.5*atan(2*sumdxdy./(sumdydy-sumdxdx));

c=cos(theta);
s=sin(theta);
XX=c*dx-s*dy;
YY=s*dx+c*dy;

sumXX=sum(XX.*XX,dimo);
sumYY=sum(YY.*YY,dimo);
varX=sumXX/(n-1);
varY=sumYY/(n-1);
a=sqrt(varX)*ks;
b=sqrt(varY)*ks;

[elx,ely]=plot_ellipse(a,b,xbar,ybar,theta);
